.. currentmodule:: xarray

.. _criteria:

CF Criteria
-----------

Attributes
~~~~~~~~~~
Criteria for identifying variables using CF attributes.

Axes
====

.. csv-table::
   :file: _build/csv/axes_criteria.csv
   :header-rows: 1
   :stub-columns: 1

Coordinates
===========

.. csv-table::
   :file: _build/csv/coords_criteria.csv
   :header-rows: 1
   :stub-columns: 1


Names
~~~~~
Regex used by :py:meth:`DataArray.cf.guess_coord_axis` and :py:meth:`Dataset.cf.guess_coord_axis` for identifying variables using their names.

.. csv-table::
   :file: _build/csv/all_regex.csv
   :stub-columns: 1

